extract method for apollo objectsextract method for apollo objects created by
apollo::apollo_estimate().
# S4 method for apollo
extract(
model,
wtpest = NULL,
se = "rob",
include.loglik = TRUE,
include.nobs = TRUE,
...
)An object of class apollo.
Optional data.frame of willingness-to-pay estimates
(and standard errors).
Which standard errors to use: "rob", "normal", or
"bs".
Report the log likelihood (including for the null model) in the GOF block?
Report the number of observations and individuals in the GOF block?
Currently ignored.
Julian Sagebiel julian.sagebiel@idiv.de, Philip Leifeld