extract method for pmg objectsextract method for pmg objects created by the
pmg function in the plm package.
# S4 method for pmg
extract(model, include.nobs = TRUE, ...)A statistical model object.
Report the number of observations in the GOF block?
Custom parameters, which are handed over to subroutines, in this
case to the summary method for the object.