extract method for prais objectsextract method for prais objects created by the
prais_winsten function in the prais package.
# S4 method for prais
extract(
model,
include.rsquared = TRUE,
include.adjrs = TRUE,
include.nobs = TRUE,
...
)A statistical model object.
Report R^2 in the GOF block?
Report adjusted R^2 in the GOF block?
Report the number of observations in the GOF block?
Custom parameters, which are handed over to subroutines, in this
case to the summary method for the object.