extract method for rlm objectsextract method for rlm objects created by the
rlm function in the MASS package.
# S4 method for rlm
extract(model, include.nobs = TRUE, ...)A statistical model object.
Report the number of observations in the GOF block?
Custom parameters, which are handed over to subroutines, in this
case to the summary method for the object.