| extract,apollo-method | R Documentation |
extract method for apollo objectsextract method for apollo objects created by
apollo::apollo_estimate().
## S4 method for signature 'apollo'
extract(
model,
wtpest = NULL,
se = "rob",
include.loglik = TRUE,
include.nobs = TRUE,
...
)
model |
An object of class |
wtpest |
Optional |
se |
Which standard errors to use: |
include.loglik |
Report the log likelihood (including for the null model) in the GOF block? |
include.nobs |
Report the number of observations and individuals in the GOF block? |
... |
Currently ignored. |
Julian Sagebiel julian.sagebiel@idiv.de, Philip Leifeld
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.