Learn R Programming

texreg (version 1.40)

knitreg: Flexibly choose the right table output format for use with knitr

Description

Flexibly choose the right table output format for use with knitr.

Usage

knitreg(...)

Value

A table as a character string in the respective output format.

Arguments

...

Arguments to be handed over to the texreg, htmlreg, screenreg, or matrixreg function. See the respective help page for details.

Author

Philip Leifeld, with input from David Hugh-Jones

Details

This function automatically selects the right function (texreg, screenreg, htmlreg, or matrixreg) with the right set of arguments for use with the knitr package, for example in RStudio. The advantage of using this function with knitr is that the user does not need to replace the texreg, htmlreg etc. function call in the document when a different output format is selected. knitr can be used directly for compiling .Rnw documents (integrating R code directly into LaTeX), with the rmarkdown package (integrating R code into Markdown and then calling Pandoc to create PDF via LaTeX, HTML, or Word .docx), or with Quarto (integrating R code and Quarto markup into Markdown and then calling Pandoc).

knitreg works with...

  • R HTML documents (.Rhtml extension)

  • R Sweave documents (.Rnw extension) for PDF output via LaTeX, rendered using...

    • the knitr package

    • the Sweave package

  • R Markdown documents (.Rmd extension), rendered as...

    • HTML documents

    • PDF documents

    • Word documents

    • Powerpoint presentations

    • Presentations (.Rpres extension, not .Rmd)

  • R Notebooks, including preview

  • Quarto documents (.qmd extension), rendered as...

    • HTML documents

    • PDF documents

    • Word documents

    • Other output formats offered by Pandoc.

If Markdown/Quarto and HTML rendering are selected, htmlreg arguments doctype = FALSE and star.symbol = "*" are set to enable compatibility with Markdown/Quarto. With R HTML documents (but not Markdown) or .Rpres presentations, only doctype = FALSE is set.

For PDF/LaTeX documents, the texreg argument use.packages = FALSE is set to suppress any package loading instructions in the preamble. The user must load any packages manually in the preamble of the document.

The knitr and rmarkdown packages must be installed for this function to work.

See Also

texreg-package extract

Other texreg: htmlreg(), huxtablereg(), matrixreg(), plotreg(), screenreg(), texreg, wordreg()

Examples

Run this code
require("nlme")
model.1 <- lme(distance ~ age, data = Orthodont, random = ~ 1)
model.2 <- lme(distance ~ age + Sex, data = Orthodont, random = ~ 1)
knitreg(list(model.1, model.2), center = FALSE, caption = "", table = FALSE)

Run the code above in your browser using DataLab